Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(72)

Unified Diff: components/web_view/frame_connection.h

Issue 1406153004: components/mus/public/interfaces View => Window (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Yet another rebase Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/web_view/frame_apptest.cc ('k') | components/web_view/frame_connection.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/web_view/frame_connection.h
diff --git a/components/web_view/frame_connection.h b/components/web_view/frame_connection.h
index 2a1d29e5f1142c2cb2da64565b8b5d411f3ae977..1d52fb0dcf2d3d00f6a669b4ab8edb9c9c30f896 100644
--- a/components/web_view/frame_connection.h
+++ b/components/web_view/frame_connection.h
@@ -8,7 +8,7 @@
#include "base/basictypes.h"
#include "base/callback.h"
#include "base/memory/scoped_ptr.h"
-#include "components/mus/public/interfaces/view_tree.mojom.h"
+#include "components/mus/public/interfaces/window_tree.mojom.h"
#include "components/web_view/frame_tree_delegate.h"
#include "components/web_view/frame_user_data.h"
#include "components/web_view/public/interfaces/frame.mojom.h"
@@ -53,8 +53,8 @@ class FrameConnection : public FrameUserData {
return application_connection_.get();
}
- // Asks the remote application for a ViewTreeClient.
- mojo::ViewTreeClientPtr GetViewTreeClient();
+ // Asks the remote application for a WindowTreeClient.
+ mus::mojom::WindowTreeClientPtr GetWindowTreeClient();
// Returns the id of the content handler app. Only available once the callback
// has run.
« no previous file with comments | « components/web_view/frame_apptest.cc ('k') | components/web_view/frame_connection.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698